@@ -1,23 +1,22 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
-#ifndef _WIN32
-#include <unistd.h>
-#define Sleep(x) usleep((x)*1000)
-#endif
 #include <nan.h>
 
+#include "sleep.h"  // NOLINT(build/include)
+
 using namespace Nan;  // NOLINT(build/namespaces)
 
 class SleepWorker : public AsyncWorker {
  public:
   SleepWorker(Callback *callback, int milliseconds)
-    : AsyncWorker(callback), milliseconds(milliseconds) {}
+    : AsyncWorker(callback, "nan:test.SleepWorker"),
+      milliseconds(milliseconds) {}
   ~SleepWorker() {}
 
   void Execute () {
@@ -29,7 +28,7 @@ class SleepWorker : public AsyncWorker {
 };
 
 NAN_METHOD(DoSleep) {
-  Callback *callback = new Callback(info[1].As<v8::Function>());
+  Callback *callback = new Callback(To<v8::Function>(info[1]).ToLocalChecked());
   AsyncQueueWorker(
       new SleepWorker(callback, To<uint32_t>(info[0]).FromJust()));
 }
@@ -37,7 +36,7 @@ NAN_METHOD(DoSleep) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("a").ToLocalChecked()
-    , New<v8::FunctionTemplate>(DoSleep)->GetFunction());
+    , GetFunction(New<v8::FunctionTemplate>(DoSleep)).ToLocalChecked());
 }
 
 NODE_MODULE(asyncworker, Init)
